@@ -838,7 +838,7 @@ sub lock_chroot {
 	my $self     = shift;
 	my $new_job  = shift;
 	my $new_pid  = shift;
-	my $new_user = shift;
+	my $new_user = quotemeta(shift);
 
 	my $lockfile      = '/var/lock/sbuild';
 	my $max_trys      = $self->get_conf('MAX_LOCK_TRYS');
